@@ -275,7 +275,17 @@ def do_action(action, args, path, package, buildopts, environ):
                     "-DAMENT_CMAKE_ENVIRONMENT_PARENT_PREFIX_PATH_GENERATION=OFF",
                     "-DAMENT_LINT_AUTO=OFF",
                 ]
+        elif action == "test" and build_type == "catkin":
+            cmdline += ["run_tests"]
 
+        for extra_args_var in [
+            f"ROS_{action.upper()}_{build_type.upper()}_COMMAND_PREFIX",
+            f"ROS_{action.upper()}_COMMAND_PREFIX",
+        ]:
+            extra_args = get_build_var(package.name, extra_args_var, env=environ)
+            if extra_args:
+                cmdline = shlex.split(extra_args) + cmdline
+                break
         for extra_args_var in [
             f"ROS_{action.upper()}_ARGS",
             f"ROS_{action.upper()}_{build_type.upper()}_ARGS",
@@ -291,6 +301,11 @@ def do_action(action, args, path, package, buildopts, environ):
         if not args.dry_run:
             subprocess.check_call(cmdline, env=env)
 
+            if action == "test" and build_type == "catkin":
+                sys.stdout.write(f"{cmdind}catkin_test_results\n")
+                sys.stdout.flush()
+                subprocess.check_call("catkin_test_results", env=env)
+
     execute_hook(
         f"after_{action}_{build_type}", package, hook_vars, env, dry_run=args.dry_run
     )
